# Support

If you need help using Fracnetics, please:

- Check the documentation: https://fracnetics.readthedocs.io/en/latest/index.html 
- Search existing issues: https://github.com/FabianKoehnke/fracnetics/issues 
- Open a new issue if needed

